@@ -1,33 +1,19 @@
 /*
- * Copyright (c) 2000 Silicon Graphics, Inc.  All Rights Reserved.
- * 
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of version 2 of the GNU General Public License as
+ * Copyright (c) 2000-2001 Silicon Graphics, Inc.
+ * All Rights Reserved.
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation.
- * 
- * This program is distributed in the hope that it would be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
- * Further, this software is distributed without any warranty that it is
- * free of the rightful claim of any third person regarding infringement
- * or the like.  Any license provided herein, whether implied or
- * otherwise, applies only to this software file.  Patent licenses, if
- * any, provided herein do not apply to combinations of this program with
- * other software, or any other product whatsoever.
- * 
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write the Free Software Foundation, Inc., 59
- * Temple Place - Suite 330, Boston MA 02111-1307, USA.
- * 
- * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
- * Mountain View, CA  94043, or:
- * 
- * http://www.sgi.com 
- * 
- * For further information regarding this notice, see: 
- * 
- * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
+ *
+ * This program is distributed in the hope that it would be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write the Free Software Foundation,
+ * Inc.,  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 #ifndef DRIVE_H
 #define DRIVE_H
@@ -113,20 +99,20 @@
  * CAUTION! the various components of the media file header are carefully
  * crafted to fit in DRIVE_HDR_SZ bytes.
  */
-#define DRIVE_HDR_SZ		sizeofmember( global_hdr_t, gh_upper )
+#define DRIVE_HDR_SZ		sizeofmember(global_hdr_t, gh_upper)
 
 struct drive_hdr {
-	u_int32_t dh_drivecnt;				/*   4    4 */
+	uint32_t dh_drivecnt;				/*   4    4 */
 		/* number of drives used to dump the fs */
-	u_int32_t dh_driveix;				/*   4    8 */
+	uint32_t dh_driveix;				/*   4    8 */
 		/* 0-based index of the drive used to dump this stream */
 	int32_t dh_strategyid;				/*   4    c */
 		/* ID of the drive strategy used to produce this dump */
-	char dh_pad1[ 0x1f4 ];				/* 1f4  200 */
+	char dh_pad1[0x1f4];				/* 1f4  200 */
 		/* padding */
-	char dh_specific[ 0x200 ];			/* 200  400 */
+	char dh_specific[0x200];			/* 200  400 */
 		/* drive strategy-specific info */
-	char dh_upper[ DRIVE_HDR_SZ - 0x400 ];		/* 800  c00 */
+	char dh_upper[DRIVE_HDR_SZ - 0x400];		/* 800  c00 */
 		/* header info private to upper software layers */
 };
 
@@ -146,23 +132,21 @@ typedef struct drive_hdr drive_hdr_t;
 struct drive;			/* forward declaration */
 
 struct drive_strategy {
-	intgen_t ds_id;
+	int ds_id;
 		    /* strategy ID
 		     */
 	char *ds_description;
 		    /* a short char string describing strategy
 		     */
-	intgen_t ( * ds_match )( intgen_t argc,
-				 char *argv[ ],
-				 struct drive *drivep,
-				 bool_t singlethreaded );
+	int (*ds_match)(int argc,
+				 char *argv[],
+				 struct drive *drivep);
 		    /* returns degree of match. drivep has been pre-allocated
 		     * and initialized with generic info.
 		     */
-	bool_t ( * ds_instantiate )( intgen_t argc,
-				     char *argv[ ],
-				     struct drive *drivep,
-				     bool_t singlethreaded );
+	bool_t (*ds_instantiate)(int argc,
+				     char *argv[],
+				     struct drive *drivep);
 		    /* creates a drive manager instance, by filling in the
 		     * blanks of the pre-allocated drive descriptor
 		     * returns FALSE on failure.
@@ -202,15 +186,15 @@ typedef off64_t drive_mark_t;
  * was NOT committed.
  */
 struct drive_markrec; /* forward decl */
-typedef void ( * drive_mcbfp_t )( void *context_t,
+typedef void (*drive_mcbfp_t)(void *context_t,
 				  struct drive_markrec *markrecp,
-				  bool_t committed );
+				  bool_t committed);
 
 /* drive_markrec_t - context for set mark callback function
  *
  * caller allocates and passes ptr to do_set_mark, along with a callback func.
  * callback returns the record, which must be freed by the original caller.
- * 
+ *
  */
 struct drive_markrec {
 	drive_mark_t dm_log;		/* identifies position within mfile */
@@ -238,6 +222,9 @@ struct drive {
 	void *d_contextp;
 				/* manager-specific data
 				 */
+	void *d_strmcontextp;
+				/* stream-specific data
+				 */
 	global_hdr_t *d_greadhdrp;
 				/* global portion of media file header of
 				 * media file drive currently positioned.
@@ -258,9 +245,9 @@ struct drive {
 	ix_t d_index;		/* e.g., 0, 1, 2, ... */
 	bool_t d_isnamedpipepr;	/* is a named pipe */
 	bool_t d_isunnamedpipepr;/* is an unnamed pipe */
-	intgen_t d_capabilities;/* see DRIVE_CAP_xxx below */
+	int d_capabilities;/* see DRIVE_CAP_xxx below */
 	off64_t d_cap_est;	/* capacity estimate in bytes; -1 if unknown */
-	intgen_t d_rate_est;	/* bytes per second; -1 if unknown */
+	int d_rate_est;	/* bytes per second; -1 if unknown */
 	drive_markrec_t *d_markrecheadp; /* linked list of mark records */
 	drive_markrec_t *d_markrectailp; /* yet to be committed */
 	off64_t d_recmarksep;	/* transfered from strategy on instantiation */
@@ -270,17 +257,17 @@ struct drive {
 typedef struct drive drive_t;
 
 struct drive_ops {
-	bool_t ( * do_init )( drive_t *drivep );
+	bool_t (*do_init)(drive_t *drivep);
 				/* initializes drive, and begins async
 				 * determination of media object presence
 				 * returns FALSE if session should be aborted.
 				 */
-	bool_t ( * do_sync )( drive_t *drivep );
+	bool_t (*do_sync)(drive_t *drivep);
 				/* synchronizes with the activity kicked off
 				 * by do_init. returns FALSE if session should
 				 * be aborted.
 				 */
-	intgen_t ( * do_begin_read )( drive_t *drivep );
+	int (*do_begin_read)(drive_t *drivep);
 				/* prepares the drive manager for reading.
 				 * if the media is positioned at BOM or just
 				 * after a file mark, current media file is
@@ -319,10 +306,10 @@ struct drive_ops {
 				 * begin_read. if successful, caller MUST call
 				 * end_read prior to next begin_read.
 				 */
-	char * ( * do_read )( drive_t *drivep,
+	char *(*do_read)(drive_t *drivep,
 			      size_t wanted_bufsz,
 			      size_t *actual_bufszp,
-			      intgen_t *statp );
+			      int *statp);
 				/* asks the drive manager for a buffered filled
 				 * with the next read stream data.
 				 * the actual buffer size supplied may
@@ -354,23 +341,23 @@ struct drive_ops {
 				 * valid data (although the buffer size may
 				 * be zero!).
 				 */
-	void ( * do_return_read_buf )( drive_t *drivep,
+	void (*do_return_read_buf)(drive_t *drivep,
 				       char *bufp,
-				       size_t bufsz );
+				       size_t bufsz);
 				/* returns the buffer obtained
 				 * from the previous do_read() call.
 				 * the entire buffer must be returned
 				 * in one shot.
 				 */
-	void ( * do_get_mark )( drive_t *drivep,
-				drive_mark_t *drivemarkp );
+	void (*do_get_mark)(drive_t *drivep,
+				drive_mark_t *drivemarkp);
 				/* returns (by reference) a mark corresponding
 				 * to the next byte which will be read by a
 				 * call to do_read(). will be used in a later
 				 * session to seek to that position.
 				 */
-	intgen_t ( * do_seek_mark )( drive_t *drivep,
-				     drive_mark_t *drivemarkp );
+	int (*do_seek_mark)(drive_t *drivep,
+				     drive_mark_t *drivemarkp);
 				/* searches for the specified mark within the
 				 * current file. returns zero if the mark
 				 * was found, or an error explaining why not:
@@ -380,7 +367,7 @@ struct drive_ops {
 				 *	CORRUPTION - encountered corrupt data;
 				 *	DEVICE - device error;
 				 */
-	intgen_t ( * do_next_mark )( drive_t *drivep );
+	int (*do_next_mark)(drive_t *drivep);
 				/* if d_capabilities has DRIVE_CAP_NEXTMARK set,
 				 * drive has the capability to
 				 * seek forward to the next mark. returns
@@ -391,14 +378,14 @@ struct drive_ops {
 				 *	DEVICE - device error;
 				 * if currently at a mark, will go to the next.
 				 */
-	void ( *do_end_read )( drive_t *drivep );
+	void (*do_end_read)(drive_t *drivep);
 				/* ends the file read. must be called prior
 				 * to beginning another read or write session.
 				 * ensures that the next call to begin_read
 				 * will position the media at the next media
 				 * file.
 				 */
-	intgen_t ( * do_begin_write )( drive_t *drivep );
+	int (*do_begin_write)(drive_t *drivep);
 				/* begins a write media file for writing.
 				 * asserts the media is positioned at BOM or
 				 * just after a file mark. write header will
@@ -409,10 +396,10 @@ struct drive_ops {
 				 *	DEVICE - device error;
 				 *	CORE  - driver error
 				 */
-	void ( * do_set_mark )( drive_t *drivep,
+	void (*do_set_mark)(drive_t *drivep,
 				drive_mcbfp_t cbfuncp,
 				void *cbcontextp,
-				drive_markrec_t *markrecp );
+				drive_markrec_t *markrecp);
 				/* marks the position in the write stream
 				 * where the next write will occur.
 				 * At the time the data written
@@ -439,9 +426,9 @@ struct drive_ops {
 				 * last committed marked point in the write
 				 * stream.
 				 */
-	char * ( * do_get_write_buf )( drive_t *drivep,
+	char *(*do_get_write_buf)(drive_t *drivep,
 				       size_t wanted_bufsz,
-				       size_t *actual_bufszp );
+				       size_t *actual_bufszp);
 				/* asks the drive manager for a buffer.
 				 * returns a pointer to a buffer, and its
 				 * size. must call do_write() before
@@ -456,9 +443,9 @@ struct drive_ops {
 				 * be larger or smaller than the wanted bufsz,
 				 * but will be at least 1 byte in length.
 				 */
-	intgen_t ( * do_write )( drive_t *drivep,
+	int (*do_write)(drive_t *drivep,
 				 char *bufp,
-				 size_t bufsz );
+				 size_t bufsz);
 				/* asks the drive manager to write bufsz
 				 * bytes from the buffer, which was acquired
 				 * from a previous call to do_get_write_buf().
@@ -486,7 +473,7 @@ struct drive_ops {
 				 * instead, the caller must get another buffer
 				 * using do_get_write_buf().
 				 */
-	size_t ( * do_get_align_cnt )( drive_t *drivep );
+	size_t (*do_get_align_cnt)(drive_t *drivep);
 				/* used during writing. returns the number
 				 * of bytes which should be written to
 				 * page-align the next do_get_write_buf()
@@ -494,7 +481,7 @@ struct drive_ops {
 				 * alignment will be maintained after the
 				 * initial alignment done using this info.
 				 */
-	intgen_t ( * do_end_write )( drive_t *drivep, off64_t *ncommittedp );
+	int (*do_end_write)(drive_t *drivep, off64_t *ncommittedp);
 				/* terminates a media file write sequence.
 				 * flushes any buffered data not yet committed
 				 * to media, and calls callbacks for all marks
@@ -515,9 +502,9 @@ struct drive_ops {
 				 * an error, do_end_write will not do any
 				 * I/O, and will return 0.
 				 */
-	intgen_t ( * do_fsf )( drive_t *drivep,
-			      intgen_t count,
-			      intgen_t *statp );
+	int (*do_fsf)(drive_t *drivep,
+			      int count,
+			      int *statp);
 				/* if d_capabilities has DRIVE_CAP_FSF set,
 				 * drive has the capability to
 				 * forward space count files. returns the
@@ -541,13 +528,13 @@ struct drive_ops {
 				 * behaves as if position is at most recent
 				 * file mark or BOT.
 				 */
-	intgen_t ( * do_bsf )( drive_t *drivep,
-			       intgen_t count,
-			       intgen_t *statp );
+	int (*do_bsf)(drive_t *drivep,
+			       int count,
+			       int *statp);
 				/* if d_capabilities has DRIVE_CAP_BSF set,
 				 * drive has the capability to backward space
 				 * count files. returns the number of actual
-				 * files backed to. 
+				 * files backed to.
 				 * can only be invoked when not reading or
 				 * writing (i.e., only after calling end_read
 				 * or end_write, or prior to calling begin_read
@@ -567,37 +554,37 @@ struct drive_ops {
 				 *	BOM - hit beginning of recorded data;
 				 *	DEVICE - device error;
 				 */
-	intgen_t ( * do_rewind )( drive_t *drivep );
+	int (*do_rewind)(drive_t *drivep);
 				/* if d_capabilities has DRIVE_CAP_REWIND set,
 				 * drive has the capability to
 				 * position at beginning of recorded data
 				 *	DEVICE - device error;
 				 */
-	intgen_t ( * do_erase )( drive_t *drivep );
+	int (*do_erase)(drive_t *drivep);
 				/* if d_capabilities has DRIVE_CAP_ERASE set,
 				 * drive has the capability to
 				 * erase: all content of media object is
 				 * eradicated.
 				 *	DEVICE - device error;
 				 */
-	intgen_t ( * do_eject_media )( drive_t *drivep );
+	int (*do_eject_media)(drive_t *drivep);
 				/* if d_capabilities has DRIVE_CAP_EJECT set,
 				 * drive has capability
 				 * to eject media, and will do so when called.
 				 *	DEVICE - device error;
 				 */
-	intgen_t ( * do_get_device_class )( drive_t *drivep );
+	int (*do_get_device_class)(drive_t *drivep);
 				/* returns the media class of the device
 				 * (see below).
 				 */
-	void ( * do_display_metrics )( drive_t *drivep );
+	void (*do_display_metrics)(drive_t *drivep);
 				/* use BARE mlog to print useful throughput
 				 * and performance info. set to NULL if
 				 * nothing to say.
 				 */
-	void ( * do_quit )( drive_t * drivep );
+	void (*do_quit)(drive_t *drivep);
 				/* tells the drive manager to de-allocate
-				 * resources, INCLUDING the slave process.
+				 * resources, INCLUDING the worker process.
 				 */
 };
 
@@ -607,24 +594,24 @@ typedef struct drive_ops drive_ops_t;
  * valid after drive_init1() returns successfully
  */
 extern drive_t **drivepp;
-extern size_t drivecnt; 
-extern size_t partialmax; 
+extern size_t drivecnt;
+extern size_t partialmax;
 
 /* drive capabilities - bit positions in the capabilities mask
  * DO NOT CHANGE: used in dh_capabilities field of scsi drive hdr.
  */
-#define DRIVE_CAP_BSF		( 1 << 0 ) /* can backspace files */
-#define DRIVE_CAP_FSF		( 1 << 1 ) /* can forwardspace files */
-#define DRIVE_CAP_REWIND	( 1 << 2 ) /* can rewind */
-#define DRIVE_CAP_FILES		( 1 << 4 ) /* supports multiple files */
-#define DRIVE_CAP_APPEND	( 1 << 5 ) /* can append to end of rec. data */
-#define DRIVE_CAP_OVERWRITE	( 1 << 6 ) /* can overwrite recorded data */
-#define DRIVE_CAP_ERASE		( 1 << 6 ) /* can erase media */
-#define DRIVE_CAP_NEXTMARK	( 1 << 8 ) /* can seek to a next good mark */
-#define DRIVE_CAP_EJECT		( 1 << 12 ) /* can eject media */
-#define DRIVE_CAP_AUTOREWIND	( 1 << 13 ) /* rewinds on media insertion */
-#define DRIVE_CAP_READ		( 1 << 14 ) /* can read media */
-#define DRIVE_CAP_REMOVABLE	( 1 << 15 ) /* can change media */
+#define DRIVE_CAP_BSF		(1 << 0) /* can backspace files */
+#define DRIVE_CAP_FSF		(1 << 1) /* can forwardspace files */
+#define DRIVE_CAP_REWIND	(1 << 2) /* can rewind */
+#define DRIVE_CAP_FILES		(1 << 4) /* supports multiple files */
+#define DRIVE_CAP_APPEND	(1 << 5) /* can append to end of rec. data */
+#define DRIVE_CAP_OVERWRITE	(1 << 6) /* can overwrite recorded data */
+#define DRIVE_CAP_ERASE		(1 << 6) /* can erase media */
+#define DRIVE_CAP_NEXTMARK	(1 << 8) /* can seek to a next good mark */
+#define DRIVE_CAP_EJECT		(1 << 12) /* can eject media */
+#define DRIVE_CAP_AUTOREWIND	(1 << 13) /* rewinds on media insertion */
+#define DRIVE_CAP_READ		(1 << 14) /* can read media */
+#define DRIVE_CAP_REMOVABLE	(1 << 15) /* can change media */
 
 /* drive manager error codes - interpretation specific to and described
  * in context of use.
@@ -659,7 +646,7 @@ extern size_t partialmax;
  *
  * Returns FALSE if utility should be aborted.
  */
-extern bool_t drive_init1( int argc, char *argv[], bool_t singlethreaded );
+extern bool_t drive_init1(int argc, char *argv[]);
 
 
 /* drive_init2 - allocate and initialize read and write hdr buffers,
@@ -668,35 +655,35 @@ extern bool_t drive_init1( int argc, char *argv[], bool_t singlethreaded );
  *
  * Returns FALSE if the session should be aborted.
  */
-extern bool_t drive_init2( int argc,
+extern bool_t drive_init2(int argc,
 			   char *argv[],
-			   global_hdr_t *gwhdrtemplatep );
+			   global_hdr_t *gwhdrtemplatep);
 
 
 /* drive_init3 - synchronize with async activity kicked off by drive_init3.
  *
  * Returns FALSE if the session should be aborted.
  */
-extern bool_t drive_init3( void );
+extern bool_t drive_init3(void);
 
 /* drive_mark_commit - invokes callback for all drive marks committed
  * to media. ncommitted is the number of bytes actually committed to
  * media so far. mark records with a mark offset less than or equal to
  * ncommitted will have their callbacks invoked.
  */
-extern void drive_mark_commit( drive_t *drivep, off64_t ncommitted );
+extern void drive_mark_commit(drive_t *drivep, off64_t ncommitted);
 
 
 /* drive_mark_discard - invokes callback of all uncommitted marks,
  * indicating the commit did not occur.
  */
-extern void drive_mark_discard( drive_t *drivep );
+extern void drive_mark_discard(drive_t *drivep);
 
 
 /* drive_display_metrics - display drive throughput and streaming metrics
  * for all drives
  */
-extern void drive_display_metrics( void );
+extern void drive_display_metrics(void);
 
 
 /* device classes
