@@ -15,9 +15,10 @@
  * along with this program; if not, write the Free Software Foundation,
  * Inc.,  51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
+#include <assert.h>
+#include <sys/types.h>
 
-#include <xfs/xfs.h>
-#include <xfs/jdm.h>
+#include "config.h"
 
 #include "types.h"
 #include "qlock.h"
@@ -26,27 +27,27 @@
 static qlockh_t lock_qlockh = QLOCKH_NULL;
 
 bool_t
-lock_init( void )
+lock_init(void)
 {
 	/* initialization sanity checks
 	 */
-	ASSERT( lock_qlockh == QLOCKH_NULL );
+	assert(lock_qlockh == QLOCKH_NULL);
 
 	/* allocate a qlock
 	 */
-	lock_qlockh = qlock_alloc( QLOCK_ORD_CRIT );
+	lock_qlockh = qlock_alloc(QLOCK_ORD_CRIT);
 
 	return BOOL_TRUE;
 }
 
 void
-lock( void )
+lock(void)
 {
-	qlock_lock( lock_qlockh );
+	qlock_lock(lock_qlockh);
 }
 
 void
-unlock( void )
+unlock(void)
 {
-	qlock_unlock( lock_qlockh );
+	qlock_unlock(lock_qlockh);
 }
